/*Copyright (C) 2010 Deveaux Duncan

This file is part of Hikou no mizu.

Hikou no mizu is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Hikou no mizu is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Hikou no mizu.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "Joueur.hpp"

Joueur::Joueur(std::string pNom, int pVies, int pEnergie, int pPuissance, int pVitesse) :
nom(pNom), vies(pVies), energie(pEnergie), puissance(pPuissance), vitesse(pVitesse)
{
	std::string cheminAnimations = "data/gfx/personnages/" + nom + "/";
	gestionAnimations = new GestionnaireAnimation(cheminAnimations, cheminAnimations + "animations.xml");
}

Joueur::~Joueur()
{
	delete gestionAnimations;
}

void Joueur::executeActions(const sf::Input &pTouches)
{	
	gestionAnimations->executeAnimation();
	
	if (pTouches.IsKeyDown(sf::Key::D)) gestionAnimations->lanceAnimation(false, 0);
	if (pTouches.IsKeyDown(sf::Key::F)) bouger(1);
	else if (pTouches.IsKeyDown(sf::Key::H)) bouger(0);
	if (pTouches.IsKeyDown(sf::Key::Z)) setSens( !getSens() );
}

void Joueur::demarreAffichage(MoteurGraphique &pMoteurRendu)
{
	gestionAnimations->demarreAffichage(pMoteurRendu);
}

void Joueur::supprimeAffichage(MoteurGraphique &pMoteurRendu)
{
	gestionAnimations->supprimeAffichage(pMoteurRendu);
}

void Joueur::bouger(int pSens)
{
	if (pSens == 0)
		gestionAnimations->setPositionAnimationsX(getPositionX() + vitesse);
	else if (pSens == 1)
		gestionAnimations->setPositionAnimationsX(getPositionX() - vitesse);
}

//Fonctions get/set
std::string Joueur::getNom() const
{
	return nom;
}

void Joueur::setVies(int pVies)
{
	vies = pVies;
}

int Joueur::getVies() const
{
	return vies;
}

void Joueur::setEnergie(int pEnergie)
{
	energie = pEnergie;
}

int Joueur::getEnergie() const
{
	return energie;
}

void Joueur::setPuissance(int pPuissance)
{
	puissance = pPuissance;
}

int Joueur::getPuissance() const
{
	return puissance;
}

void Joueur::setVitesse(int pVitesse)
{
	vitesse = pVitesse;
}

int Joueur::getVitesse() const
{
	return vitesse;
}

void Joueur::setJoueurAdverse(Joueur *pJoueurAdverse)
{
	joueurAdverse = pJoueurAdverse;
}

Joueur *Joueur::getJoueurAdverse() const
{
	return joueurAdverse;
}

void Joueur::setSens(int pSens)
{
	if (pSens == 0 || pSens == 1)
	{
		gestionAnimations->setSensAnimations(pSens);
	}
}

int Joueur::getSens() const
{
	return gestionAnimations->getSensAnimations();
}

void Joueur::setPositionX(float pPosition)
{
	gestionAnimations->setPositionAnimationsX(pPosition);
}

float Joueur::getPositionX() const
{
	return gestionAnimations->getPositionAnimationsX();
}

void Joueur::setPositionY(float pPosition)
{
	gestionAnimations->setPositionAnimationsY(pPosition);
}

float Joueur::getPositionY() const
{
	return gestionAnimations->getPositionAnimationsY();
}
